@@ -1,7 +1,7 @@
 gof <- function( glmfit, pcutoff=0.1, adjust="holm", plot=FALSE, main="qq-plot of residual deviances", ...)
 #	Compare residual deviances to chisquare distribution to identify dispersion outlier genes
 #	Davis McCarthy, Gordon Smyth
-#	23 Mar 2011. Last modified 23 May 2012.
+#	23 Mar 2011. Last modified 2 Jun 2020.
 {
 	stopifnot( is(glmfit, "DGEGLM") )
 	gof.stats <- glmfit$deviance
@@ -11,9 +11,9 @@ gof <- function( glmfit, pcutoff=0.1, adjust="holm", plot=FALSE, main="qq-plot o
 	if(plot) {
 		n <- length(gof.stats)
 		z <- zscoreGamma(gof.stats,shape=glmfit$df.residual/2,scale=2)
-		col <- rep("black",n)
+		col <- rep_len("black",n)
 		col[outlier] <- "blue"
-		pch <- rep(1,n)
+		pch <- rep_len(1,n)
 		pch[outlier] <- 16
 		qqnorm(z,col=col,pch=pch,main=main,...)
 		abline(0,1)
