@@ -2,13 +2,15 @@ goodTuring <- function(x, conf=1.96)
 #	Simple Good-Turing algorithm for frequency estimation
 #	as described by Gale and Sampson (1995)
 
-#  Sampson's C code translated to C++ and optimized by Aaron Lun
+#	Sampson's C code translated to C++ and optimized by Aaron Lun
 #	Has been tested against Sampson's C code from
 #	http://www.grsampson.net/RGoodTur.html
 #	and gives identical results.
 
-#	Gordon Smyth and Aaron Lun
-#	9 Nov 2010.  Last modified 7 Sep 2012.
+#	R version by Gordon Smyth
+#	C++ version by Aaron Lun
+#	C version by Lizhong Chen
+#	Created 9 Nov 2010.  Last modified 13 May 2024.
 {
 #	Raw frequencies
 	x <- as.integer(x)
@@ -34,8 +36,7 @@ goodTuring <- function(x, conf=1.96)
 	}
 
 #	SGT algorithm (no type checking, as that's enforced above)
-	out <- .Call(.cxx_simple_good_turing, r, n, conf)
-	names(out) <- c("P0","proportion")
+	out <- .Call(.cxx_simple_good_turing, r, n, as.double(conf))
 
 	out$count <- r
 	out$n <- n
