@@ -1,10 +1,11 @@
 maximizeInterpolant <- function( x, y ) 
-# maximizeInterpolant: written by Aaron Lun
-#
-# This function takes an ordered set of spline points and a likelihood matrix where each row 
+# Takes an ordered set of spline points and a likelihood matrix where each row 
 # corresponds to a tag and each column corresponds to a spline point. It then calculates the 
 # position at which the maximum interpolated likelihood occurs for each by solving the derivative
 # of the spline function.
+# C++ by Aaron Lun.
+# C by Lizhong Chen.
+# Last modified 13 May 2024.
 {
     if (is.vector(y)) {
         y<-rbind(y)
@@ -17,9 +18,6 @@ maximizeInterpolant <- function( x, y )
     }
 
 #	Performing some type checking.
-	if (!is.double(x)) storage.mode(x)<-"double"
-	if (!is.double(y)) storage.mode(y)<-"double"
-    out<-.Call(.cR_maximize_interpolant, x, t(y))
-	if (is.character(out)) { stop(out) }
-    return(out);
+    out<-.Call(.cxx_maximize_interpolant, x, y)
+    return(out)
 }
